@@ -2,11 +2,9 @@ import sqlalchemy as sa
 from .builders import ImproperlyConfigured
 from .manager import translation_manager, TranslationManager, translation_base
 from .translatable import Translatable, UnknownLocaleError
-from .utils import default_locale
 
 
 __all__ = (
-    default_locale,
     translation_base,
     ImproperlyConfigured,
     Translatable,
@@ -16,7 +14,7 @@ __all__ = (
 )
 
 
-__version__ = '0.8.2'
+__version__ = '0.8.4'
 
 
 def make_translatable(
@@ -25,6 +23,19 @@ def make_translatable(
     manager=translation_manager,
     options={}
 ):
+    """
+    Assigns translation listeners for given mapper and session.
+
+    :param mapper:
+        SQLAlchemy declarative class or mapper to apply translation listeners
+        into.
+    :param session:
+        SQLAlchemy session class.
+    :param manager:
+        SQLAlchemy-i18n TranslationManager instance
+    :param options:
+        TranslationManager options
+    """
     manager.options.update(options)
 
     sa.event.listen(
@@ -52,7 +63,7 @@ def find_translations(obj, property_name, locale):
                 property_ ==
                 getattr(obj, property_name),
                 translation_class.locale ==
-                default_locale(obj)
+                obj.locale
             )
         )
     )
@@ -60,7 +71,7 @@ def find_translations(obj, property_name, locale):
     conditions = [
         translation_class.id.in_(subquery),
         translation_class.locale == locale,
-        property_ != None
+        property_.isnot(None)
     ]
 
     total_count = (
